@@ -25,9 +25,10 @@ class Algo:
         self.log.set_name(GUID)
         self.data_source = data_source
         self.GUID = GUID
-        self.tick_period = int(config["tick_period"])
         self.orders = []
         self.positions = {}
+        self.tick_period = int(config["tick_period"])       # the interval of the algo in seconds.
+                                                            # if its run every day, the interval is 86400, for example
         order_manager.log = self.log
         self.order_manager = order_manager
         self.tickers = order_manager.tickers
@@ -179,9 +180,46 @@ class AlgoMeanReversionBuckets(Algo):
     def print_details(self):
         return "{}, {}, {}, {}".format(self.data_points, self.stddev, self.rsi_high, self.rsi_low)
 
+class AlgoRebalancing(Algo):
+    def __init__ (self, order_manager, data_path, data_source, GUID, config):
+        super().__init__(order_manager, data_path, data_source, GUID,config)
+        
+    def run(self, return_dict):
+        super().run()
+        proportions = []
+        equity = self.order_manager.get_total_value()
+        for t in self.tickers:
+            proportions.append(1.0/len(self.tickers))
 
-
-
+        to_buy = []
+        to_sell = []
+        for i, t in enumerate(self.tickers):
+            desired_value = proportions[i] * equity
+            
+            current_pos = self.data_source.get_position(t)
+            current_value = float(current_pos["market_value"])
+            current_share_price = float(current_pos["current_price"])
+            if current_share_price == 0:
+                current_share_price = self.data_source.get_last_trade(t)["price"]
+            
+            # first I want to sell.
+            # then i want to buy
+            
+            if desired_value == current_pos:
+                continue
+            if desired_value > current_value:
+                shares_to_buy = int((desired_value-current_value)/current_share_price)
+                to_buy.append((t,shares_to_buy,current_share_price))
+            if desired_value < current_value:
+                shares_to_sell = int((current_value-desired_value)/current_share_price)
+                to_sell.append((t,shares_to_sell,current_share_price))
+        self.order_manager.rebalance(to_sell, to_buy)
+        
+        self.log.output()
+        self.data_source.quick_test = True
+        self.data_source.step(self.tick_period)
+        super().run_end()
+        return_dict[self.GUID] = (self.order_manager.wallet, self.positions)
 
 class AlgoFactory():
     def __init__(self, type="RSI_BB"):
@@ -196,6 +234,14 @@ class AlgoFactory():
                 GUID=GUID,
                 config=config
                 )
+        if self.type == "REBALANCING":
+            return AlgoRebalancing(
+                order_manager=order_manager,
+                data_path=data_path,
+                data_source=data_source,
+                GUID=GUID,
+                config=config
+                )
         return
         
     def setType(self, type):
