@@ -21,7 +21,7 @@ import configparser
 ##################################################################################
 '''============================================================================'''
 
-from order import OrderManager
+from order import *
 from algos import *
 from util import log as log
 from util import DataSource
