@@ -43,7 +43,6 @@ class OrderManager:
             self.init_buy[t] = True # Not used rn
             self.positions[t] = 0
         self.mem_file = data_path + "algo_mem/{}.pkl".format(GUID)
-
     def _buy(self, ticker, quantity, price):
         capital_out = 0
         # Goes through local order list and updates using live list
@@ -90,6 +89,7 @@ class OrderManager:
                 limit_price=price,
                 time_in_force='gtc'
                 )
+
                 info = (response['id'])
                 self.orders.append(info)
 
@@ -164,7 +164,6 @@ class OrderManager:
         except Exception as e:
             self.log.error("Cannot save algo: ")
             self.log.error(e)
-
     def load_algo(self):
         if self.quick_test: return
         try:
@@ -180,18 +179,15 @@ class OrderManager:
         except Exception as e:
             self.log.warn("Cannot load algo. Creating a mem file...   "   + str(e))
             self.save_algo()
+    def print_details(self):
+        return "{}, {}".format(self.buy_percent, self.sell_percent)
+    
+
+class RsiOrderManager(OrderManager):
+    def __init__(self, GUID, data_path, data_source, config, open_orders):
+        super().__init__(GUID, data_path, data_source, config, open_orders)
+
     def sell_proportional(self, ticker):
-        # Check sell queue for too many open orders. Update wallet accordingly
-        # orders = self.data_source.list_orders('sell')
-        # total_investment_out = 0
-        # new_orders = []
-        # for order in orders:
-        #     if(self.orders.find(order['id'])):
-        #         new_orders.append(self.orders[order['id']]) #add orders that are still open to new list
-        #         total_investment_out += order['qty'] * order['limit_price']
-        # self.orders = new_orders
-        # while total_investment_out > self.threshold: #Cancel oldest current open order on this process (front)
-        #
         try:
             self.log.info("sell_proportional {}".format(ticker))
             pos = self.data_source.get_position(ticker)
@@ -204,7 +200,7 @@ class OrderManager:
             if qty == 0:
                 self.log.info("sell_proportional no shares to sell")
                 return
-            self._sell(ticker, qty, price)
+            super()._sell(ticker, qty, price)
             self.log.info("SELL Partial {} shares of {}".format(qty, ticker))
         except Exception as e:
             self.log.error("sell_proportional error: {} ".format(e))
@@ -217,7 +213,7 @@ class OrderManager:
             price = float(self.data_source.get_last_trade(ticker)["price"])
             total_cost = price * float(self.buy_qty[ticker])
             if (balance - (total_cost * 1.01)> 25000.0):
-                self._buy(ticker, self.buy_qty[ticker], price)
+                super()._buy(ticker, self.buy_qty[ticker], price)
                 self.log.info("BUY {} shares of {}".format(self.buy_qty[ticker], ticker))
             else:
                 raise Exception("Not enough wallet value. Cost:{} / Balance:{}".format(total_cost, balance))
@@ -226,4 +222,50 @@ class OrderManager:
             
     def print_details(self):
         return "{}, {}".format(self.buy_percent, self.sell_percent)
+
+class DailyRebalancer(OrderManager):
+    def __init__(self, GUID, data_path, data_source, config, open_orders):
+        super().__init__(GUID, data_path, data_source, config, open_orders)
+        
+    def rebalance(self, to_sell, to_buy):
+        self.log.info("Started Rebalancing on Order Manager")
+        # Go through each ticker and wallet value. Calculate how much 
+        # value of each ticker i should have
+        for sell in to_sell:
+            self._sell(*sell)
+        for buy in to_buy:
+            self._buy(*buy)
+    def get_total_value(self):
+        total_value = self.wallet
+        
+        for t in self.tickers:
+            ticker_price = self.data_source.get_last_trade(t)["price"]
+            total_value += self.positions[t] * ticker_price
+        return total_value
+        
+class OrderManagerFactory():
+    def __init__(self, type="DEFAULT"):
+        self.type = type
+        
+    def build(self, data_path, data_source, GUID, order_config, open_orders):
+        if self.type == "RSI":
+            return RsiOrderManager(
+                        GUID=GUID,
+                        data_path=data_path,
+                        data_source=data_source,
+                        config=order_config,
+                        open_orders = open_orders
+                        )
+        if self.type == "REBALANCING":
+            return DailyRebalancer(
+                        GUID=GUID,
+                        data_path=data_path,
+                        data_source=data_source,
+                        config=order_config,
+                        open_orders = open_orders
+                        )
+        return
+        
+    def setType(self, type):
+        self.type = type
     
\ No newline at end of file
