@@ -217,17 +217,23 @@ class DataSource:
         if (self.mode == backtest):
             return self.backtester.get_position(ticker)
         try:
-            qty =  self.api_endpoint.get_position(ticker).qty
-        except:
+            pos =  self.api_endpoint.get_position(ticker)
+            qty = pos.qty
+            market_value = pos.market_value
+            current_price = pos.current_price
+        except Exception as e:
             qty = 0
-        ret = {"qty" : qty}
+            market_value = 0
+            current_price = 0
+
+        ret = {"qty" : qty, "market_value" : market_value, "current_price" : current_price }
         return ret
 
     def get_account(self):
         if (self.mode == backtest):
             return self.backtester.get_account()
         act = self.api_endpoint.get_account()
-        ret = {"cash" : act.cash}
+        ret = {"cash" : act.cash, "equity" : act.equity}
         return ret
 
     def list_orders(self, side):
@@ -252,9 +258,13 @@ class DataSource:
             pass
 
     def submit_order(self, ticker, quantity, side, type, limit_price, time_in_force):
+        info = {"limit_price" : 0,
+                "qty" : 0,
+                "id" : 0}
         try:
             if (self.mode == backtest):
                 return self.backtester.submit_order(ticker, quantity, side, type, limit_price, time_in_force)
+                            
             response = self.api_endpoint.submit_order(
             symbol=ticker,
             qty=quantity,
@@ -263,6 +273,7 @@ class DataSource:
             limit_price=limit_price,
             time_in_force=time_in_force
             )
+            
             info = {"limit_price" : response.limit_price,
                     "qty" : response.qty,
                     "id" : response.id}
@@ -270,6 +281,7 @@ class DataSource:
 
         except Exception as e:
             log.info("DATA SOURCE ERROR: submit_order()         " + str(e))
+            return info
     def cancel_order(self, order_id):
         try:
             if (self.mode == backtest):
